######################################
# Parse-CustomDate FUNCTION #
######################################

#$DATE = (get-date).ToString('yyyyMMdd')
#$TransDate = "July 10"
#$TransYear = "2018"
#$TRUNKDATE = $TransDate,$TransYear -join" "

#$TimeString = "2:21:02 PM"

# Convert date formatting
function Parse-CustomDate {
    param(
        [Parameter(Mandatory=$true)]
        [string]$DateString,
        [string]$DateFormat = 'MMMMMMMMM %d yyyy',
        [cultureinfo]$Culture = $(New-Object System.Globalization.CultureInfo -ArgumentList "en-US")
    )

    # replace double space by a single one
    $DateString = $DateString -replace '\s+',' '

    [Datetime]::ParseExact($DateString, $DateFormat, $Culture)
}

######################################
# END OF Parse-CustomDate FUNCTION #
#####################################

######################################
# Parse-CustomTime FUNCTION #
#####################################

function Parse-CustomTime {
    param(
        [Parameter(Mandatory=$true)]
        [string]$TimeString,
        [string]$TimeFormat = '%h:mm:ss tt',
        [cultureinfo]$Culture = $(New-Object System.Globalization.CultureInfo -ArgumentList "en-US")
    )

    # replace double space by a single one
    $TimeString = $TimeString -replace '\s+',' '

    [Datetime]::ParseExact($TimeString, $TimeFormat, $Culture)
}

#$TIME = Parse-CustomTime -TimeString $TimeString
#Write-Host $TIME.ToString('HHmmss')

#$DATED = Parse-CustomDate -DateString "$TRUNKDATE"

#Write-Host "TransDate: $TransDate"
#Write-Host "TransYear: $TransYear"
#Write-Host "Date: $DATE"

#Write-Host "DATED: "$DATED.ToString('yyyyMMdd')

######################################
# END OF Parse-CustomTime FUNCTION #
#####################################





######################################
# GETTOKEN FUNCTION #
######################################

# GetToken
#."$HOMEDIR\Scripts\GetToken.ps1"

function gettoken {
#."$HOMEDIR\scripts\variables.ps1"


try{
	IF( !(Test-Path $TOKENFILE))
		{

        $GETTOKEN = Invoke-RestMethod -Method Get -Uri $LOGINURL

		Write-Host "Getting a token..."

		
		$GETTOKEN | export-csv -Path $TOKENFILE -NoTypeInformation
		
		Write-Host "Setting token for job..."
		
		$TOKEN = Import-CSV $TOKENFILE -header status, token, expdate
            ForEach ($COLUMN in $TOKEN){
                $global:TOKENSTATUS=$($TOKEN.status[1])
                $global:TOKENVAL=$($TOKEN.token[1])
                $global:TOKENEXP=$($TOKEN.expdate[1])
            }
		}
	ELSE {
		Write-Host "Checking Token Expiration..."

            $TOKEN = Import-CSV $TOKENFILE -header status, token, expdate
            ForEach ($COLUMN in $TOKEN){
                $global:TOKENSTATUS=$($TOKEN.status[1])
                $global:TOKENVAL=$($TOKEN.token[1])
                $global:TOKENEXP=$($TOKEN.expdate[1])
            }

			IF ($TOKENEXP -lt $DATE){

			Write-Host "Token expired: "$TOKENEXP
			
			Write-Host "Getting a new token..."
			
			Remove-Item $TOKENFILE -Force
			
			Write-Host "Creating CSV for token..."

			$GETTOKEN | export-csv -Path $TOKENFILE -NoTypeInformation
			}
			ELSE{
			OUT-NULL
			}
		Write-Host "Token has not expired..."
		
		}
}

catch{
Write-Host "Bad things happened when trying to get a token!"
}
}

######################################
# END OF GETTOKEN FUNCTION #
######################################